@@ -1,10 +1,6 @@
 from saratoga import AuthenticationFailed
 from twisted.internet import defer
 
-import hashlib
-import hmac
-
-
 
 class InMemoryStringSharedSecretSource(object):
 
@@ -62,18 +58,21 @@ class DefaultAuthenticator(object):
         return defer.maybeDeferred(self._getUserDetails, username).addCallback(_continue)
 
 
-    def auth_HMAC(self, username, hmacUser, content, algorithm):
+    def auth_HMAC(self, username, request):
 
         def _continue(result):
 
-            algo = getattr(hashlib, algorithm)
+            import httpsig.verify
 
-            hmacObj = hmac.new(result.get("password"), content, algo)
+            head = {x.lower():y[0] for x,y in request.requestHeaders.getAllRawHeaders()}
+            hs = httpsig.verify.HeaderVerifier(headers=head,
+                                               secret=result.get("password"),
+                                               method=request.method,
+                                               path=request.path)
+            res = hs.verify()
 
-            hmacResult = hmacObj.hexdigest()
-
-            if hmacUser == hmacResult:
-                uName = result.get("canonicalUsername", result.get("Username"))
+            if res:
+                uName = result.get("canonicalUsername", )
                 return defer.succeed(uName)
 
             raise AuthenticationFailed("Authentication failed.")
